Documentation
¶
Index ¶
Constants ¶
const ( ENV_SANDBOX = Sandbox("https://connect.squareupsandbox.com") ENV_PRODUCTION = Production("https://connect.squareup.com") )
Variables ¶
var Environments = struct { Sandbox Sandbox Production Production }{ Sandbox: ENV_SANDBOX, Production: ENV_PRODUCTION, }
Environment has part of the domain that varies with the environment.
Functions ¶
This section is empty.
Types ¶
type Env ¶
type Env interface {
Sandbox | Production
}
Environment has part of the domain that varies with the environment.
type Production ¶
type Production string
Click to show internal directories.
Click to hide internal directories.