square

package module
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 20, 2023 License: Apache-2.0 Imports: 0 Imported by: 0

README

Square Go SDK

go license star

Tags

go square

Installation

go install github.com/KoeInoue/square-go-sdk

Minimal Example

package main

import "github.com/KoeInoue/square-go-sdk"

func main() {

}

Contributors

Users

Documentation

Index

Constants

const (
	ENV_SANDBOX    = Sandbox("https://connect.squareupsandbox.com")
	ENV_PRODUCTION = Production("https://connect.squareup.com")
)

Variables

var Environments = struct {
	Sandbox    Sandbox
	Production Production
}{
	Sandbox:    ENV_SANDBOX,
	Production: ENV_PRODUCTION,
}

Environment has part of the domain that varies with the environment.

Functions

This section is empty.

Types

type Config

type Config[T Env] struct {
	AccessToken string
	Environment T
}

Config struct contains access token and environment

type Env

type Env interface {
	Sandbox | Production
}

Environment has part of the domain that varies with the environment.

type Production

type Production string

type Sandbox

type Sandbox string

Directories

Path Synopsis

Jump to